products property
Returns a list of GooglePlayUserChoiceDetailsProduct to be purchased in the user choice alternative billing flow.
Implementation
final List<GooglePlayUserChoiceDetailsProduct> products;
Returns a list of GooglePlayUserChoiceDetailsProduct to be purchased in the user choice alternative billing flow.
final List<GooglePlayUserChoiceDetailsProduct> products;