InAppMessageResponse enum
Response code for the in-app messaging API call.
Values
- noActionNeeded → const InAppMessageResponse
-
The flow has finished and there is no action needed from developers.
Note: The API callback won't indicate whether message is dismissed by the user or there is no message available to the user.
- subscriptionStatusUpdated → const InAppMessageResponse
-
The subscription status changed.
For example, a subscription has been recovered from a suspended state. Developers should expect the purchase token to be returned with this response code and use the purchase token with the Google Play Developer API.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
InAppMessageResponse> - A constant List of the values in this enum, in order of their declaration.